@@ -11,7 +11,7 @@ setuptools.setup(
     author_email="abhay@trell.in",
     name='trell_ai_utils',
     description='Utility code for trell ai repos',
-    version='v0.0.8',
+    version='v0.0.18',
     long_description=README,
     url='https://gitlab.com/abhay7/trell-ai-util',
     packages=setuptools.find_packages(),
@@ -20,7 +20,7 @@ setuptools.setup(
                       'google-cloud==0.34.0', 'google-cloud-bigquery==1.23.1', 'mysql-connector==2.2.9',
                         'mysql-replication==0.22', "subprocess32==3.5.4", "psutil==5.6.7",
                       "Flask == 1.1.1", "SQLAlchemy == 1.3.12", "SQLAlchemy-JSONField==0.9.0",
-                      "SQLAlchemy-Utils==0.36.8",
+                      "SQLAlchemy-Utils==0.36.8", "boto","boto3",
                       ],
     classifiers=[
         # Trove classifiers
